@@ -1,9 +1,10 @@
 import argparse
 from argparse import RawTextHelpFormatter
 import sys
-import clustpipeline
-from scripts.glob import version
-import scripts.output as op
+import clust.clustpipeline as clustpipeline
+from clust.scripts.glob import version
+import clust.scripts.output as op
+import warnings
 
 
 def main(args=None):
@@ -23,12 +24,11 @@ def main(args=None):
     headertxt += op.midline()
     headertxt += op.msgformated('Citation\n'
                                 '~~~~~~~~', '^')
-    citationtxt = 'When publishing work that uses Clust, please include these two citations:\n' \
-                  '1. Basel Abu-Jamous and Steven Kelly (2018) Clust: automatic extraction of optimal co-expressed ' \
-                  'gene clusters from gene expression data. bioRxiv 221309; doi: https://doi.org/10.1101/221309.\n' \
-                  '2. Basel Abu-Jamous, Rui Fa, David J. Roberts, and Asoke K. Nandi (2013) Paradigm of tunable ' \
-                  'clustering using binarisation of consensus partition matrices (Bi-CoPaM) for gene discovery, ' \
-                  'PLOS ONE, 8(2): e56432'
+    citationtxt = 'When publishing work that uses Clust, please cite:\n' \
+                  'Basel Abu-Jamous and Steven Kelly (2018) Clust: automatic extraction of optimal co-expressed ' \
+                  'gene clusters from gene expression data. Genome Biology 19:172; ' \
+                  'doi: https://doi.org/10.1186/s13059-018-1536-8.'
+    # TODO: citation
     headertxt += op.msgformated(citationtxt, '<')
     headertxt += op.midline()
     headertxt += op.msgformated('Full description of usage can be found at:\n'
@@ -36,7 +36,7 @@ def main(args=None):
     headertxt += op.bottomline()
 
     parser = argparse.ArgumentParser(description=headertxt, formatter_class=RawTextHelpFormatter)
-    parser.add_argument('datapath', help='The directory that includes the data files.', default=None)
+    parser.add_argument('datapath', help='Data file path or directory with data file(s).', default=None)
     parser.add_argument('-n', metavar='<file or int>', help='Normalisation file or list of codes (default: 1000)', default=['1000'], nargs='+')
     parser.add_argument('-r', metavar='<file>', help='Replicates structure file', default=None)
     parser.add_argument('-m', metavar='<file>', help='OrthoGroups (OGs) mapping file', default=None)
@@ -74,9 +74,10 @@ def main(args=None):
     parser.add_argument('--no-optimisation', dest='optimisation', action='store_false',
                         help='Skip cluster optimsation & completion')
     parser.add_argument('--deterministic', dest='deterministic', action='store_true',
-                        help='Obsolete as all steps are already deterministic (v1.7.4+)')
-    parser.add_argument('-np', metavar='<integer>', type=int, help='Number of parallel processes (default: 1)',
+                        help='Obsolete. All steps are already deterministic (v1.7.4+)')
+    parser.add_argument('-np', metavar='<integer>', type=int, help='Obsolete. Number of parallel processes (default: 1)',
                         default=1)
+
     parser.set_defaults(optimisation=True, deterministic=False, absval=False, filperc=False, filflat=True)
     # parser.add_argument('-ec', type=int, help='Perform error correction, 1 or 0 (default: 1)', default=1)
 
@@ -85,6 +86,9 @@ def main(args=None):
 
     args = parser.parse_args(args)
 
+    if args.np > 1:
+        warnings.warn('The -np option is obsolete and is forced to be 1 in v1.10.5+. It is set to 1.')
+        args.np = 1
     if args.filperc:
         filtype = 'perc'
     else:
